@@ -10,10 +10,10 @@ from alphabase.constants.element import (
 
 from alphabase.constants._const import CONST_FILE_FOLDER
 
+
+#: Main entry of modification infomation (DataFrame fotmat).
 MOD_DF:pd.DataFrame = pd.DataFrame()
-"""
-Main entry of modification infomation (DataFrame fotmat).
-"""
+
 
 MOD_INFO_DICT:dict = {}
 #: Modification to formula str dict. {mod_name: formula str ('H(1)C(2)O(3)')}
@@ -22,7 +22,7 @@ MOD_CHEM:dict = {}
 MOD_MASS:dict = {}
 #: Modification to modification neutral loss dict.
 MOD_LOSS_MASS:dict = {}
-#: Modification to formula dict of dict. i.e. {modname: {'C': n, 'H': m, ...}}
+#Modification to formula dict of dict, i.e. {modname: {'C': n, 'H': m, ...}}
 MOD_formula:dict = {}
 #: Modification loss importance
 MOD_LOSS_IMPORTANCE:dict = {}
@@ -356,24 +356,12 @@ def calc_modloss_mass(
     else:
         return _calc_modloss(mod_losses[::-1])[-3:0:-1]
 
-def add_a_new_modification(
+def _add_a_new_modification(
     mod_name:str, composition:str,
     modloss_composition:str=''
 ):
     """
     Add a new modification into :data:`MOD_DF`.
-
-    Parameters
-    ----------
-    mod_name : str
-        Mod name in alphabase format: mod@site, 
-        e.g. Mod@S
-    composition : str
-        chemical composition of this mod, 
-        e.g. "H(4)O(2)"
-    modloss_composition : str, optional
-        modloss compositions, e.g. "H(2)O(1)"), 
-        by default ''
     """
     MOD_DF.loc[mod_name,[
         'mod_name','composition','modloss_composition',
@@ -387,23 +375,38 @@ def add_a_new_modification(
         calc_mass_from_formula(modloss_composition)
     )
     if MOD_DF.loc[mod_name, 'modloss'] > 0:
-        MOD_DF.loc[mod_name, 'modloss_importance'] = 1e6
+        MOD_DF.loc[mod_name, 'modloss_importance'] = 1e10
     MOD_DF.fillna(0, inplace=True)
-    update_all_by_MOD_DF()
+    # update_all_by_MOD_DF()
 
-def add_new_modifications(new_mods:list):
-    """Add multiple modifications into :data:`MOD_DF`,
-    it uses :meth:`add_a_new_modification()`.
+def add_new_modifications(new_mods:Union[list,dict]):
+    """Add new modifications into :data:`MOD_DF`.
 
     Parameters
     ----------
-    new_mods : list of tuples
-        Tuple example:
-        (
-        modname@site:str (e.g. Mod@S), 
+    new_mods : list or dict
+        list of tuples example:
+        ```
+        [(
+        mod@site:str (e.g. Mod@S), 
         composition:str (e.g. "H(4)O(2)"),
         [optional] modloss composition:str (e.g. "H(2)O(1)"),
-        )
+        ), ...]
+        ```,
+        dict example:
+        ```
+        {
+        "mod@site": {
+        "composition":"H(4)O(2)",
+        "modloss_composition":"H(2)O(1)"
+        }, ...
+        }
+        ```
     """
-    for items in new_mods:
-        add_a_new_modification(*items)
+    if isinstance(new_mods, list):
+        for items in new_mods:
+            _add_a_new_modification(*items)
+    else:
+        for mod_name, mod_info in new_mods.items():
+            _add_a_new_modification(mod_name, **mod_info)
+    update_all_by_MOD_DF()
